@@ -137,8 +137,6 @@ class Crp:
         df_matrix = self.getLastOrderValue(df_matrix,train_df)
 
 
-
-
         
         output = df_matrix 
         
@@ -208,7 +206,7 @@ class Crp:
         return output
 # -----------------------------------------------------------------------------------------------
 
-    def buildDF(original_dataset,lag,train_window,items_dataset):
+    def buildDF(self,original_dataset,lag,train_window,items_dataset):
         """
         Params:
             original_dataset - > the original raw data 
